Please don't file issues directly, use one of our available templates:

Bugs: https://github.com/martibosch/pylandstats/issues/new?template=bug.md
Feature Requests: https://github.com/martibosch/pylandstats/issues/new?template=feature.md

Thank you.
